@@ -6,6 +6,7 @@ export * from './colors.js';
 export * from './comms.js';
 export * from './datetimes.js';
 export * from './deaths.js';
+export * from './devices.js';
 export * from './diagnoses.js';
 export * from './documents.js';
 export * from './encounters.js';
@@ -21,6 +22,7 @@ export * from './medications.js';
 export * from './notes.js';
 export * from './patientFields.js';
 export * from './patientDetails.js';
+export * from './permissions.js';
 export * from './referenceData.js';
 export * from './reports.js';
 export * from './servers.js';
