@@ -1,6 +1,6 @@
 import config from 'config';
 import { log } from '@tamanu/shared/services/logging';
-import { selectFacilityIds } from '@tamanu/shared/utils/configSelectors';
+import { selectFacilityIds } from '@tamanu/utils/selectFacilityIds';
 
 export async function checkConfig({ settings, models }) {
   const ensureExists = async (modelName, code) => {
